@@ -1,38 +1,40 @@
 /* ============================================================
-* Date        : 2008-08-26
-* Description : Preview image viewer.
-*
-* SPDX-FileCopyrightText: 2008-2012 Kåre Särs <kare.sars@iki .fi>
-*
-* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
-*
-* ============================================================ */
+ * Date        : 2008-08-26
+ * Description : Preview image viewer.
+ *
+ * SPDX-FileCopyrightText: 2008-2012 Kåre Särs <kare.sars@iki .fi>
+ *
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ *
+ * ============================================================ */
 
 #include "ImageViewer.h"
 
+#include <QAction>
 #include <QGraphicsPixmapItem>
 #include <QGraphicsScene>
-#include <QScrollBar>
-#include <QAction>
 #include <QIcon>
+#include <QScrollBar>
 #include <QWheelEvent>
 
 #include <KLocalizedString>
 
 struct ImageViewer::Private {
-    QGraphicsScene      *scene;
-    QImage              *img;
+    QGraphicsScene *scene = nullptr;
+    QImage *img = nullptr;
 
-    QAction *zoomInAction;
-    QAction *zoomOutAction;
-    QAction *zoom100Action;
-    QAction *zoom2FitAction;
+    QAction *zoomInAction = nullptr;
+    QAction *zoomOutAction = nullptr;
+    QAction *zoom100Action = nullptr;
+    QAction *zoom2FitAction = nullptr;
 };
 
-ImageViewer::ImageViewer(QWidget *parent) : QGraphicsView(parent), d(new Private)
+ImageViewer::ImageViewer(QWidget *parent)
+    : QGraphicsView(parent)
+    , d(new Private)
 {
-    //setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
-    //setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
+    // setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
+    // setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
     setMouseTracking(true);
 
     // Init the scene
@@ -46,10 +48,10 @@ ImageViewer::ImageViewer(QWidget *parent) : QGraphicsView(parent), d(new Private
     d->zoomOutAction = new QAction(QIcon::fromTheme(QStringLiteral("zoom-out")), i18n("Zoom Out"), this);
     connect(d->zoomOutAction, &QAction::triggered, this, &ImageViewer::zoomOut);
 
-    d->zoom100Action = new QAction(QIcon::fromTheme(QStringLiteral("zoom-fit-best")), i18n("Zoom to Actual size"), this);
+    d->zoom100Action = new QAction(QIcon::fromTheme(QStringLiteral("zoom-original")), i18n("Zoom to Actual size"), this);
     connect(d->zoom100Action, &QAction::triggered, this, &ImageViewer::zoomActualSize);
 
-    d->zoom2FitAction = new QAction(QIcon::fromTheme(QStringLiteral("document-preview")), i18n("Zoom to Fit"), this);
+    d->zoom2FitAction = new QAction(QIcon::fromTheme(QStringLiteral("zoom-fit-best")), i18n("Zoom to Fit"), this);
     connect(d->zoom2FitAction, &QAction::triggered, this, &ImageViewer::zoom2Fit);
 
     addAction(d->zoomInAction);
@@ -121,15 +123,12 @@ void ImageViewer::wheelEvent(QWheelEvent *e)
     if (e->modifiers() == Qt::ControlModifier) {
         if (e->angleDelta().y() > 0) {
             zoomIn();
-        }
-        else {
+        } else {
             zoomOut();
         }
-    }
-    else {
+    } else {
         QGraphicsView::wheelEvent(e);
     }
 }
 
-
 #include "moc_ImageViewer.cpp"
